


********************************************************************************
********************************************************************************
*******************              DO-FILE FOR:               ********************
**********       Intragroup Communication in Social Dilemmas:        ***********
**   An Artefactual Public Good Field Experiment in Small-Scale Communities   **

                 * Author: Nils Christian Hoenow 
                 * Contact: christian.hoenow@rwi-essen.de
                 * Last updated: September 2023

********************************************************************************
********************************************************************************



clear all
set more off

* Folder to be adjusted
cd "L:\2022\comm_data\Data"
use "Dataset_Communication.dta", clear



/// *** 1. preparing data *** ///

* destringing variables
destring D_control1, replace
destring D_control2, replace
destring D_contribute, replace
destring D_treatment, replace
destring D_belief, replace 
destring S_G_age, replace
destring S_G_schoolingyears, replace
destring S_EX_ladder, replace
destring S_A_cattle, replace
destring D_ID, replace

destring H_GI_villagesize , replace
destring H_GI_villagepop , replace
destring H_GI_villagehouseholds , replace
destring H_A_yields , replace
destring H_A_incometotal , replace
destring H_A_coveredforestshare , replace
destring H_A_coveredforestsqkm , replace
destring H_A_coveredfieldsshare , replace

destring S_GI_totalincome , replace
destring S_GI_incomefarming , replace
destring S_GI_soldfarming , replace
destring S_GI_totalfarming, replace
destring S_G_householdadults, replace
destring S_G_householdchildren, replace

destring S_AR_anongroupsamehousehold S_AR_anongroupfriends S_AR_anongroupacquaintances S_AR_anongroupunknown, replace 
destring S_GR_groupsamehousehold S_GR_groupfriends S_GR_groupacquaintances S_GR_groupunknown, replace


destring S_GI_householdequipmentelectric, replace
destring S_GI_householdequipmentgenerato, replace
destring S_GI_householdequipmentradio, replace
destring S_GI_householdequipmenttelevisi, replace
destring S_GI_householdequipmentrefriger, replace
destring S_GI_householdequipmentmotorize , replace
destring S_GI_householdequipmentbicycle, replace
destring S_GI_householdequipmentphone , replace

destring S_MQ_smalltalkgreeting S_MQ_smalltalkagriculture S_MQ_smalltalkparticipants S_MQ_smalltalkjoking S_MQ_smalltalkmoney S_MQ_smalltalkexpectations S_MQ_smalltalkcoordination S_MQ_smalltalkexplain S_MQ_smalltalkdifferentdecision, replace

*creating string for treatments
gen Treatment_str = "none"
replace Treatment_str = "Anonymity" if D_treatment == 1
replace Treatment_str = "no communication" if D_treatment == 2
replace Treatment_str = "unrelated" if D_treatment == 3
replace Treatment_str = "dilemma-related" if D_treatment == 4


/// *** 2. preparing new and auxiliary variables *** ///

*gen Village_IDs for clustering
gen Village_ID = .
replace Village_ID = 1 if H_today == "01may2017" 
replace Village_ID = 2 if H_today == "02may2017" 
replace Village_ID = 3 if H_today == "05may2017" 
replace Village_ID = 4 if H_today == "08may2017"
replace Village_ID = 5 if H_today == "10may2017" 
replace Village_ID = 6 if H_today == "11may2017" 
replace Village_ID = 7 if H_today == "12may2017"
replace Village_ID = 8 if H_today == "15may2017" 
replace Village_ID = 9 if H_today == "16may2017" 
replace Village_ID = 10 if H_today == "29may2017" 
replace Village_ID = 11 if H_today == "16jun2017"
replace Village_ID = 12 if H_today == "20jun2017"
replace Village_ID = 13 if H_today == "21jun2017"
replace Village_ID = 14 if H_today == "23jun2017"

xtset Village_ID // to be changed if xt-set on other cluster
replace Village_ID = 8 if D_Excel_date == "15 m a y 2017" & D_ID == 8

*treatment_id
egen Treatmentgroup_ID = concat ( Village_ID D_treatment)
destring Treatmentgroup_ID, replace

*group_id
egen Gamegroup_ID = concat ( Village_ID D_treatment D_group)
destring Gamegroup_ID, replace

* expectations aka "beliefs"
gen Belief = D_belief

* head of household
gen Head_HH = .
replace Head_HH = 1 if S_G_householdhead == "yes"
replace Head_HH = 0 if S_G_householdhead == "no"

*village variables
gen Born_vill = .
replace Born_vill = 1 if S_EX_born == "yes"
replace Born_vill = 0 if S_EX_born == "no"
gen Born_village = Born_vill

gen H_School = .
replace H_School = 1 if H_G_villageschool == "yes"
replace H_School = 0 if H_G_villageschool == "no"

gen H_Health = .
replace H_Health = 1 if H_G_villagehealth == "yes"
replace H_Health = 0 if H_G_villagehealth == "no"

gen H_CommForest = .
replace H_CommForest = 1 if H_G_villagecommunityforest == "yes"
replace H_CommForest = 0 if H_G_villagecommunityforest == "no"



*** Cleaning Survey Data ***
gen S_female = 0
replace S_female = 1 if S_GI_gender == "female"

gen S_HHead = 0
replace S_HHead = 1 if S_G_householdhead == "yes"

gen S_Farmer = 0
replace S_Farmer = 1 if S_GI_professionfarming == "yes"

replace S_G_age = . if S_G_age >150
replace S_G_age = . if S_G_age < 12

replace S_G_schoolingyears = 4 if S_G_schoolingyears > 25  //person will be dropped later on anyway

destring S_LT_fieldhectar, replace
destring S_LT_clearedhowmuch, replace

gen S_E_Born = .
replace S_E_Born = 1 if S_EX_born == "yes"
replace S_E_Born = 0 if S_EX_born == "no"

destring S_GI_soldfarming, replace 
destring S_GI_incomefarming, replace

gen S_L_fertilizer = 0
replace S_L_fertilizer = 1 if S_A_fertilizers == "yes"
   
* Extra vars
gen S_Extra_HypCoop = .
replace S_Extra_HypCoop = 0 if S_EX_thousandnad == "1000NADforyourself"
replace S_Extra_HypCoop = 1 if S_EX_thousandnad == "100NADforeveryone"

destring S_EX_ladder, replace

*** renaming variables for analysis ***
gen Age = S_G_age 
gen Female = S_female 
gen Schooling_years = S_G_schoolingyears 
gen Head_of_hh = S_HHead 
gen Adults_in_hh = S_G_householdadults 
gen Kids_in_hh = S_G_householdchildren 
gen Bags_farming_yield = S_GI_totalfarming 
gen Income_farming = S_GI_incomefarming 
gen Income_total = S_GI_totalincome 
gen Cattle_owned = S_A_cattle 
gen Hectares_cultivated = S_LT_fieldhectar   
gen Social_ladder = S_EX_ladder 
gen Farmer = S_Farmer 
gen Village_native = S_E_Born 

gen Assets_Index = S_GI_householdequipmentelectric+ S_GI_householdequipmentgenerato+ S_GI_householdequipmentradio+ S_GI_householdequipmenttelevisi+ S_GI_householdequipmentrefriger+ S_GI_householdequipmentmotorize +S_GI_householdequipmentbicycle+ S_GI_householdequipmentphone 
    
gen Fertilizer = S_L_fertilizer


* gen Migration variables
gen Migrant20 = 0 // as defined by not born int and < 20 years in village
replace Migrant20 = 1 if S_EX_lived == "five"
replace Migrant20 = 1 if S_EX_lived == "lessthanfive"
replace Migrant20 = 1 if S_EX_lived == "ten"

gen Migrant10 = 0 // as defined by not born int and < 10 years in village
replace Migrant10 = 1 if S_EX_lived == "five"
replace Migrant10 = 1 if S_EX_lived == "lessthanfive"

gen Migrant5 = 0 // as defined by not born int and < 5 years in village
replace Migrant5 = 1 if S_EX_lived == "lessthanfive"

* delta in beliefs vs contributions
gen delta = .
replace delta = D_contribute - Belief


*generating per capita values
gen Bags_farming_yield_pc = Bags_farming_yield / Adults_in_hh
gen Income_farming_pc = Income_farming / Adults_in_hh
gen Income_total_pc = Income_total / Adults_in_hh
gen Cattle_owned_pc = Cattle_owned / Adults_in_hh
gen Hectares_cultivated_pc = Hectares_cultivated / Adults_in_hh


* for regression set maximum for some variables in order to reduce detorioration caused by outliers (and possibly unreasonable values) 
 * exchanging extremely high value with large but realistic value -> try to avoid using this var if possible
gen Cattle_owned_r = Cattle_owned
gen Cattle_owned_pc_r = Cattle_owned_pc
replace Cattle_owned_r = 500 if Cattle_owned > 500
replace Cattle_owned_pc_r = 250 if Cattle_owned_pc > 500

** Generating dummies for exmperimenters and  assistants **
gen Experimenter_Adrian = 0
replace Experimenter_Adrian = 1 if D_Experimenter == "adrian"

gen Assistant_Moses = 0
replace Assistant_Moses = 1 if D_Assistant == "moses"

** Generating dummies for treatments **
gen Treat1 = 0
gen Treat2 = 0
gen Treat3 = 0
gen Treat4 = 0
replace Treat1 = 1 if D_treatment == 1
replace Treat2 = 1 if D_treatment == 2
replace Treat3 = 1 if D_treatment == 3
replace Treat4 = 1 if D_treatment == 4

gen T_Anonymity = Treat1
gen T_Identification = Treat2
gen T_Smalltalk = Treat3
gen T_Coordination = Treat4

label variable T_Smalltalk  "T1: Unrelated"
label variable  T_Coordination "T2: Dilemma-related"

** group composition **

*T234 only:
gen Family = S_GR_groupsamehousehold 
gen Friends = S_GR_groupfriends 
gen Acquaintancies = S_GR_groupacquaintances 
gen Unknown = S_GR_groupunknown 

gen FamFds = S_GR_groupsamehousehold + S_GR_groupfriends
label variable FamFds "FamFds"

* T1: calculate  average group composition *
gen A_T1groupHH_sh = S_AR_anongroupsamehousehold/ 11 
gen A_T1groupFDS_sh = S_AR_anongroupfriends / 11
gen A_T1groupACQ_sh = S_AR_anongroupacquaintances / 11
gen A_T1groupUN_sh = S_AR_anongroupunknown / 11

* T2-4: calculate average group composition * 
gen A_T24groupHH_sh = S_GR_groupsamehousehold / 3
gen A_T24groupFDS_sh = S_GR_groupfriends / 3
gen A_T24groupACQ_sh = S_GR_groupacquaintances / 3
gen A_T24groupUN_sh = S_GR_groupunknown / 3

* generate a variable for all treatments *
gen A_groupHH_sh = A_T24groupHH_sh
gen A_groupFDS_sh = A_T24groupFDS_sh
gen A_groupACQ_sh = A_T24groupACQ_sh
gen A_groupUN_sh = A_T24groupUN_sh

replace A_groupHH_sh = A_T1groupHH_sh if D_treatment == 1
replace A_groupFDS_sh = A_T1groupFDS_sh if D_treatment == 1
replace A_groupACQ_sh = A_T1groupACQ_sh if D_treatment == 1
replace A_groupUN_sh = A_T1groupUN_sh if D_treatment == 1

gen A_FamFds_sh = A_groupHH_sh + A_groupFDS_sh

gen Family_share = A_groupHH_sh
gen Friends_share = A_groupFDS_sh
gen Acquaintances_share = A_groupACQ_sh
gen Unknown_share = A_groupUN_sh

gen FamFds_share = A_groupHH_sh + A_groupFDS_sh
gen AcqUnkw_share = A_groupACQ_sh + A_groupUN_sh

* Dummy
gen Socialties_d = 0
replace Socialties_d = 1 if Family_share > 0
replace Socialties_d = 1 if Friends_share > 0

gen Family_d = 0
replace Family_d = 1 if Family_share > 0

gen Friends_d = 0
replace Friends_d = 1 if Friends_share > 0



* group characteristics *
*** indicating homogeneity of the group in terms of: gender, age, education, religion, language, wealth, migration background, trust
* Contributions:
 bys Gamegroup_ID: egen G_groupMean = mean(D_contribute)
 bys Gamegroup_ID: egen G_groupSD = sd(D_contribute)	
 
 bys Gamegroup_ID: egen G_groupMExp = mean(Belief)
 bys Gamegroup_ID: egen G_groupSDExp = sd(Belief)		
 
 gen G_groupSum = G_groupMean*4
 gen G_groupSum3others = G_groupSum - D_contribute
 
 bys D_treatment: egen Betweengroups_SD = sd(G_groupMean)
 
 *Language:
 
 *Religion:
 
 *Age: 
 bys Gamegroup_ID: egen G_groupAge = mean(Age)
 bys Gamegroup_ID: egen G_groupSDAge = sd(Age)
 *Belief:
 bys Gamegroup_ID: egen G_groupBelief = mean(Belief)
 bys Gamegroup_ID: egen G_groupSDBelief = sd(Belief)
 *Schooling:
 bys Gamegroup_ID: egen G_groupSchooling = mean(Schooling)
 bys Gamegroup_ID: egen G_groupSDSchooling = sd(Schooling)
 *Ladder:
 bys Gamegroup_ID: egen G_groupLadder = mean(Social_ladder)
 bys Gamegroup_ID: egen G_groupSDLadder = sd(Social_ladder)
 *Cattle:
 bys Gamegroup_ID: egen G_groupCattle = mean(Cattle_owned)
  bys Gamegroup_ID: egen G_groupSDCattle = sd(Cattle_owned)
 *Gender:
 bys Gamegroup_ID: egen G_groupFemale = mean(Female)
 bys Gamegroup_ID: egen G_groupSDFemale = sd(Female)
 *HHHead:
 bys Gamegroup_ID: egen G_groupHeadHH = mean(Head_of_hh)
 bys Gamegroup_ID: egen G_groupSDHeadHH = sd(Head_of_hh)

* Trust variables
gen Trustgeneral = 0
replace Trustgeneral = 1 if S_EX_trustgeneral == "trusted"

gen TrustVillage = .
replace TrustVillage = 1 if S_EX_trustvillage == "not.at.all"
replace TrustVillage = 2 if S_EX_trustvillage == "not.very.much"
replace TrustVillage = 3 if S_EX_trustvillage == "somewhat"
replace TrustVillage = 4 if S_EX_trustvillage == "completely"

gen TrustWorkshop = .
replace TrustWorkshop = 1 if S_EX_trustworkshop == "not.at.all"
replace TrustWorkshop = 2 if S_EX_trustworkshop == "not.very.much"
replace TrustWorkshop = 3 if S_EX_trustworkshop == "somewhat"
replace TrustWorkshop = 4 if S_EX_trustworkshop == "completely"

gen TrustGroup = .
replace TrustGroup = 1 if S_EX_trustgroup == "not.at.all"
replace TrustGroup = 2 if S_EX_trustgroup == "not.very.much"
replace TrustGroup = 3 if S_EX_trustgroup == "somewhat"
replace TrustGroup = 4 if S_EX_trustgroup == "completely"


*hypothetical cooperation
gen HypMoneyCooperate = .
replace HypMoneyCooperate = 0 if S_EX_thousandnad == "1000NADforyourself"
replace HypMoneyCooperate = 1 if S_EX_thousandnad == "100NADforeveryone"

local list_gamestats "D_contribute Belief Family_share Friends_share FamFds_share Trustgeneral TrustVillage TrustWorkshop TrustGroup  Experimenter_Adrian Assistant_Moses"
local list_socioeconomics_full "Age Female Schooling_years Head_of_hh Adults_in_hh Kids_in_hh Village_native Migrant20 Migrant10 Migrant5 Bags_farming_yield Hectares_cultivated Assets_Index Cattle_owned Social_ladder"
local list_socioeconomics "Age Female Schooling_years Head_of_hh Adults_in_hh Kids_in_hh Village_native Migrant10 Bags_farming_yield Hectares_cultivated Assets_Index Cattle_owned Social_ladder"
local list_experimenters "Experimenter_Adrian Assistant_Moses"
local list_group "G_groupMean G_groupSD G_groupSum Betweengroups_SD G_groupAge G_groupSDAge G_groupBelief G_groupSDBelief G_groupSchooling G_groupSDSchooling G_groupLadder G_groupSDLadder G_groupCattle G_groupSDCattle G_groupFemale G_groupSDFemale G_groupHeadHH G_groupSDHeadHH"

local list_groupmeans "G_groupBelief G_groupAge G_groupFemale G_groupSchooling G_groupHeadHH G_groupCattle G_groupLadder"   
local list_groupSDs "G_groupSDBelief G_groupSDAge G_groupSDFemale  G_groupSDSchooling G_groupSDHeadHH  G_groupSDCattle G_groupSDLadder "

replace Bags_farming_yield = 0 if Bags_farming_yield > 9999999

gen Control_wrong = 0
replace Control_wrong = 1 if D_control1 == 1
replace Control_wrong = 1 if D_control2 == 1


* generate expectation (belief) additional variables
gen Delta_Beliefs = Belief - G_groupMean
tabulate D_treatment, summarize ( Delta_Beliefs)
tabulate D_treatment if D_treatment < 3 & Control_wrong == 0, summarize ( Delta_Beliefs) 
tabulate D_treatment if D_treatment > 1 & Control_wrong == 0, summarize ( Delta_Beliefs) 

gen Correct_Belief = 0
replace Correct_Belief = 1 if Delta_Beliefs < 1
tabulate D_treatment, summarize ( Correct_Belief)
tabulate D_treatment if D_treatment < 3 & Control_wrong == 0, summarize ( Correct_Belief) 
tabulate D_treatment if D_treatment > 1 & Control_wrong == 0, summarize ( Correct_Belief) 

** give newly generated variables proper labels
label variable Belief "Expectation"
label variable Age "Age"
label variable Female "Female (d)"
label variable Schooling_years "Schooling years"
label variable Adults_in_hh "Adults in hh"
label variable Migrant10 "Migrant (d)"
label variable Bags_farming_yield "Bags yield"
label variable Hectares_cultivated "Hectares"
label variable Farmer "Farmer (d)"
label variable Control_wrong "Control Q. wrong"



/// *** 2. Cleaning Data *** //// 
 
drop if H_GI_villagename == "Manyondo" // unwanted comunication in Christian's group
drop if H_GI_villagename == "Erago village" // unwanted communication in Christian's group

*drop if D_control1 == 1 // control Q1 not answered correctly
*drop if D_control2 == 1 // control Q2 not answered correctly

** clean one person (m) who left early
replace Schooling_years = . if M_UID == "15 m a y 2017_2_8"
replace Migrant10 = . if M_UID == "15 m a y 2017_2_8"
replace Bags_farming_yield = . if M_UID == "15 m a y 2017_2_8"
replace Farmer = . if M_UID == "15 m a y 2017_2_8"
replace Cattle_owned_pc_r = . if M_UID == "15 m a y 2017_2_8"
replace S_female = 0 if M_UID == "15 m a y 2017_2_8" // it was a man



** labelling treatment conditions
gen L_treatment = D_treatment
label def Treatmentlabel 1 "T0: anonymity" 2 "No communication" 3 "Unrelated" 4 "Dilemma-related" 
label values L_treatment Treatmentlabel


* creating locals for analyses
local usedvars FamFds Age Female Adults_in_hh Schooling_years Migrant10 Bags_farming_yield Hectares_cultivated Farmer
local mtreatments "Treatment_2 Treatment_4 Treatment_3"
local socialties "FamFds"
local socioeconomics "Age Female Schooling_years Hectares_cultivated Bags_farming_yield Farmer Migrant10"
local agriculturals "   "
local experimentereffects "  "










//////// *****                  R E S U L T S                    ***** ////////

**********       Intragroup Communication in Social Dilemmas:        ***********
**   An Artefactual Public Good Field Experiment in Small-Scale Communities   **


* Tables and Figures are presented in the same order as in the paper:
* sometimes, additional tests are conducted even though they were not included in the paper






*** Table 1: Summary statistics and variable description ***
eststo allvars: quietly estpost summarize D_contribute Belief TrustGroup Control_wrong  `socialties' `socioeconomics' `agriculturals' if D_treatment > 1 
esttab allvars, cells("mean(pattern(1 1 0) fmt(2)) sd(pattern(1 1 0)) min(pattern(1 1 0) fmt(0))  max(pattern(1 1 0) fmt(0))") label
*for correctly understood PGG
eststo allvars: quietly estpost summarize D_contribute  Belief TrustGroup `socialties' `socioeconomics' `agriculturals'  if D_treatment > 1 & Control_wrong == 0 
esttab allvars, cells("mean(pattern(1 1 0) fmt(2)) sd(pattern(1 1 0)) min(pattern(1 1 0) fmt(0))  max(pattern(1 1 0) fmt(0))") label


*** Table 2: Split sample by experimental groups ***
eststo Anonymity: quietly estpost summarize ///
     `socialties' `socioeconomics' `agriculturals' if D_treatment == 1
eststo Identification: quietly estpost summarize ///
     `socialties' `socioeconomics' `agriculturals' if D_treatment == 2
eststo Smalltalk: quietly estpost summarize ///
     `socialties' `socioeconomics' `agriculturals' if D_treatment == 3
eststo Coordination: quietly estpost summarize ///
     `socialties' `socioeconomics' `agriculturals' if D_treatment == 4
esttab Anonymity Identification Smalltalk Coordination, cells("mean(fmt(2))") label 
esttab Identification Smalltalk Coordination, cells("mean(fmt(2))") label

** Test results for comparing treatment groups: Table.2:
* Kruska-Wallis test for ratio scaled variables over three groups
* chi2 or fisher exact for binary variables, also over more than two groups

kwallis D_contribute if D_treatment > 1, by(D_treatment)  
kwallis Belief if D_treatment > 1, by(D_treatment)  
kwallis TrustGroup if D_treatment > 1, by(D_treatment) 
kwallis Family if D_treatment > 1, by(D_treatment)  
kwallis Friends if D_treatment > 1, by(D_treatment)  
 
kwallis FamFds if D_treatment > 1, by(D_treatment)  
kwallis Age if D_treatment > 1, by(D_treatment)  
tab D_treatment Female if D_treatment > 1, exact  
kwallis Schooling_years if D_treatment > 1, by(D_treatment) 
kwallis Hectares_cultivated if D_treatment > 1, by(D_treatment)
kwallis Bags_farming_yield if D_treatment > 1, by(D_treatment)
tab D_treatment Farmer if D_treatment > 1, exact  
tab D_treatment Migrant10 if D_treatment > 1, exact 


 




*** Table 3: not produced with data *** 






*** Table 4: Comparison between experimental conditions and tests ***

**  CONTRIBUTIONS  **
*overall
kwallis D_contribute if D_treatment >1 , by(D_treatment)
* testing for significant differences between single treatments: TTEST
ttest D_contribute if  D_treatment ==2 | D_treatment == 3, by(D_treatment) // *
ttest D_contribute if  D_treatment ==2 | D_treatment == 4, by(D_treatment) // ***
ttest D_contribute if  D_treatment ==3 | D_treatment == 4, by(D_treatment) // ***
* for contributions distinction between understood/misunderstood see analysis of comprehension

* 1. correct CQ:
* testing for significant differences between single treatments: TTEST
ttest D_contribute if Control_wrong == 0 & D_treatment ==2 | Control_wrong == 0 &D_treatment == 3, by(D_treatment) // *
ttest D_contribute if Control_wrong == 0 & D_treatment ==2 | Control_wrong == 0 &D_treatment == 4, by(D_treatment) // ***
ttest D_contribute if Control_wrong == 0 & D_treatment ==3 | Control_wrong == 0 &D_treatment == 4, by(D_treatment) // ***
* 2. wrong CQ:
* testing for significant differences between single treatments: TTEST
ttest D_contribute if Control_wrong == 1 & D_treatment ==2 | Control_wrong == 1 &D_treatment == 3, by(D_treatment) // 
ttest D_contribute if Control_wrong == 1 & D_treatment ==2 | Control_wrong == 1 &D_treatment == 4, by(D_treatment) // 
ttest D_contribute if Control_wrong == 1 & D_treatment ==3 | Control_wrong == 1 &D_treatment == 4, by(D_treatment) // 


**  VARIABILITY  **
preserve
keep if D_ID == 1| D_ID ==5 | D_ID ==9 
** Variability of Contributions**
* testing for significant differences between single treatments: TTEST
ttest G_groupSD if  D_treatment ==2 | D_treatment == 3, by(D_treatment) // *
ttest G_groupSD if  D_treatment ==2 | D_treatment == 4, by(D_treatment) // ***
ttest G_groupSD if  D_treatment ==3 | D_treatment == 4, by(D_treatment) // ***
sum G_groupMExp
sum G_groupSDExp 	
 
** Variability of Expectations **
* testing for significant differences between single treatments: TTEST
ttest G_groupSDExp if  D_treatment ==2 | D_treatment == 3, by(D_treatment) // *
ttest G_groupSDExp if  D_treatment ==2 | D_treatment == 4, by(D_treatment) // ***
ttest G_groupSDExp if  D_treatment ==3 | D_treatment == 4, by(D_treatment) // ***

restore

** EXPECTATIONS  **
* testing for significant differences between single treatments: TTEST
ttest Belief if D_treatment ==2 | D_treatment == 3, by(D_treatment) // 
ttest Belief if D_treatment ==2 | D_treatment == 4, by(D_treatment) // 
ttest Belief if D_treatment ==3 | D_treatment == 4, by(D_treatment) // 

**  Share of correctly stated expectations  **
* testing for significant differences between single treatments: CHI2
tab D_treatment , sum(Correct_Belief)
tab D_treatment Correct_Belief if D_treatment ==2 | D_treatment == 3 , chi2 // 
tab D_treatment Correct_Belief if D_treatment ==2 | D_treatment == 4 , chi2 // ***
tab D_treatment Correct_Belief if D_treatment ==3 | D_treatment == 4 , chi2 // **

** TRUST  **
* testing for significant differences between single treatments: TTEST
ttest TrustGroup if D_treatment ==2 | D_treatment == 3, by(D_treatment) // 
ttest TrustGroup if D_treatment ==2 | D_treatment == 4, by(D_treatment) // 
ttest TrustGroup if D_treatment ==3 | D_treatment == 4, by(D_treatment) // 


/*

** Variance analysis **
tabulate D_treatment, summarize (G_groupMean) // more variation between groups in T2
tabulate D_treatment if D_ID == 1| D_ID ==5 | D_ID ==9, summarize (G_groupMean) // more variation between groups in T2 - better measure

tabulate D_treatment , summarize (G_groupSD)
tabulate D_treatment if D_ID == 1| D_ID ==5 | D_ID ==9, summarize (G_groupSD)

sdtest G_groupMean if  D_treatment>2 & D_ID == 1| D_treatment>2 & D_ID ==5 | D_treatment>2 & D_ID ==9  , by (D_treatment)
sdtest G_groupMean if  D_treatment<3 & D_ID == 1| D_treatment<3 & D_ID ==5 | D_treatment<3 & D_ID ==9  , by (D_treatment)

robvar G_groupMean if  D_treatment>2 & D_ID == 1| D_treatment>2 & D_ID ==5 | D_treatment>2 & D_ID ==9  , by (D_treatment)
robvar G_groupMean if  D_treatment<3 & D_ID == 1| D_treatment<3 & D_ID ==5 | D_treatment<3 & D_ID ==9  , by (D_treatment)

tabulate D_treatment, summarize (G_groupSD) // more variation within groups in T1
tabulate D_treatment ,summarize (G_groupSD)
tabulate D_treatment if D_ID == 1| D_ID ==5 | D_ID ==9, summarize (G_groupSD)

tabulate D_treatment ,summarize (Betweengroups_SD)

ttest G_groupSD if D_treatment <3, by(D_treatment)
ttest G_groupSD if D_treatment >2, by(D_treatment)

*/










 *** Table 5: Basic Tobit regression models for contributions to public good *** 

* Tobit, model 1
tobit D_contribute   T_Smalltalk T_Coordination if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) 
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store model_1
* Tobit, model 2
tobit D_contribute Belief T_Smalltalk T_Coordination FamFds `socioeconomics' `agriculturals' `experimentereffects'   if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) 
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store model_2
* Tobit, model 3
tobit D_contribute   T_Smalltalk T_Coordination if D_treatment > 1 & Control_wrong == 0, ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) 
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store model_3
* Tobit, model 4
tobit D_contribute Belief T_Smalltalk T_Coordination FamFds `socioeconomics' `agriculturals' `experimentereffects'   if D_treatment > 1 & Control_wrong == 0, ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) 
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store model_4

estout model_1 model_2 model_3 model_4 , cells(b(star fmt(3)) se(par fmt(2))) label legend varlabels(_cons constant) stats(N, fmt(3 3 3 0) label(N))  starlevels(* 0.05 ** 0.01 *** 0.001)




 *** Table 6: Tobit regression models for contributions to public good with interaction effects *** 

* Tobit, model 5
tobit D_contribute   T_Smalltalk##c.FamFds T_Coordination##c.FamFds Belief `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) 
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins, dydx(T_Smalltalk T_Coordination) at(FamFds=(0 1 2 3)) 
estimates store model_5
* Tobit, model 6
tobit D_contribute   T_Smalltalk##i.FamFds T_Coordination##i.FamFds Belief `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) 
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins FamFds, dydx(T_Smalltalk T_Coordination) atmeans
estimates store model_6
* Tobit, model 7
tobit D_contribute   T_Smalltalk##c.FamFds T_Coordination##c.FamFds Belief `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 & Control_wrong == 0, ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) 
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins, dydx(T_Smalltalk T_Coordination) at(FamFds=(0 1 2 3)) 
estimates store model_7
* Tobit, model 8
tobit D_contribute   T_Smalltalk##i.FamFds T_Coordination##i.FamFds Belief `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 & Control_wrong == 0, ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) 
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins FamFds, dydx(T_Smalltalk T_Coordination) atmeans
estimates store model_8

estout model_5 model_6 model_7 model_8 , cells(b(star fmt(3)) se(par fmt(2))) label legend varlabels(_cons constant) stats(N, fmt(3 3 3 0) label(N))  starlevels(* 0.05 ** 0.01 *** 0.001)







*** Figure 2: Contributions by treatment condition and social contexts ***
preserve
*drop if Control_wrong == 1
egen controlmean = mean(D_contribute) if D_treatment == 2
egen unrelatedmean = mean(D_contribute) if D_treatment == 3
egen relatedmean = mean(D_contribute) if D_treatment == 4
gen FF_one = round(FamFds, 1)
bysort FF_one: egen contribution_meanFFT2 = mean(D_contribute) if D_treatment == 2
bysort FF_one: egen contribution_meanFFT3 = mean(D_contribute) if D_treatment == 3
bysort FF_one: egen contribution_meanFFT4 = mean(D_contribute) if D_treatment == 4
local varstoround contribution_meanFFT2 contribution_meanFFT3 contribution_meanFFT4

foreach y of local varstoround {

replace `y' = round(`y', 0.01)
}

* the figure is constructed of 4 parts in order to allow for varying positions of value labels
twoway  /// 
        (scatter contribution_meanFFT2 FF_one if D_treatment == 2, connect(direct) sort(FF_one) mlabel(contribution_meanFFT2) lpattern(solid) lwidth(medium) mlabformat(%9.2fc) mlabposition(5) msize(small) mlabcolor(gs5) mcolor(gs5) lcolor(gs5)) ///  
        (scatter contribution_meanFFT3 FF_one if D_treatment == 3, connect(direct) sort(FF_one) mlabel(contribution_meanFFT3) lpattern(dash) lwidth(medium) mlabformat(%9.2fc) mlabposition(5) msize(small) mlabcolor(gs5) mcolor(lavender) lcolor(lavender)) ///  
        (scatter contribution_meanFFT4 FF_one if D_treatment == 4, connect(direct) sort(FF_one) mlabel(contribution_meanFFT4) lpattern(longdash) lwidth(medium) mlabformat(%9.2fc) mlabposition(1) msize(small) mlabcolor(gs5) mcolor(navy) lcolor(navy)) ///        
        (line controlmean FF_one if D_treatment == 2,  lwidth(medthick) lcolor(gs5) lpattern(dot)) ///
        (line unrelatedmean FF_one if D_treatment == 3, lwidth(medthick) lcolor(lavender) lpattern(dot)) ///
        (line relatedmean FF_one if D_treatment == 4, lwidth(medthick) lcolor(navy) lpattern(dot)) ///
        , legend(order(1 "Control" 2 "T1: Unrelated" 3 "T2: Dilemma-related" 4 "DEL")) ///
          xtitle(number of family members and friends in group) ytitle("average contributions") ///
          ysc(r(0 10)) ylabel(0(2)10, grid) graphregion(color(white)) bgcolor(white)

twoway  /// 
        (scatter contribution_meanFFT2 FF_one if D_treatment == 2, connect(direct) sort(FF_one) mlabel(contribution_meanFFT2) lpattern(solid) lwidth(medium) mlabformat(%9.2fc) mlabposition(6) msize(small) mlabcolor(gs5) mcolor(gs5) lcolor(gs5)) ///  
        (scatter contribution_meanFFT3 FF_one if D_treatment == 3, connect(direct) sort(FF_one) mlabel(contribution_meanFFT3) lpattern(dash) lwidth(medium) mlabformat(%9.2fc) mlabposition(12) msize(small) mlabcolor(gs5) mcolor(lavender) lcolor(lavender)) ///  
        (scatter contribution_meanFFT4 FF_one if D_treatment == 4, connect(direct) sort(FF_one) mlabel(contribution_meanFFT4) lpattern(longdash) lwidth(medium) mlabformat(%9.2fc) mlabposition(12) msize(small) mlabcolor(gs5) mcolor(navy) lcolor(navy)) ///        
        (line controlmean FF_one if D_treatment == 2,  lwidth(medthick) lcolor(gs5) lpattern(dot)) ///
        (line unrelatedmean FF_one if D_treatment == 3, lwidth(medthick) lcolor(lavender) lpattern(dot)) ///
        (line relatedmean FF_one if D_treatment == 4, lwidth(medthick) lcolor(navy) lpattern(dot)) ///
        , legend(order(1 "Control" 2 "T1: Unrelated" 3 "T2: Dilemma-related" 4 "DEL")) ///
          xtitle(number of family members and friends in group) ytitle("average contributions") ///
          ysc(r(0 10)) ylabel(0(2)10, grid) graphregion(color(white)) bgcolor(white)
		  
twoway  /// 
        (scatter contribution_meanFFT2 FF_one if D_treatment == 2, connect(direct) sort(FF_one) mlabel(contribution_meanFFT2) lpattern(solid) lwidth(medium) mlabformat(%9.2fc) mlabposition(6) msize(small) mlabcolor(gs5) mcolor(gs5) lcolor(gs5)) ///  
        (scatter contribution_meanFFT3 FF_one if D_treatment == 3, connect(direct) sort(FF_one) mlabel(contribution_meanFFT3) lpattern(dash) lwidth(medium) mlabformat(%9.2fc) mlabposition(6) msize(small) mlabcolor(gs5) mcolor(lavender) lcolor(lavender)) ///  
        (scatter contribution_meanFFT4 FF_one if D_treatment == 4, connect(direct) sort(FF_one) mlabel(contribution_meanFFT4) lpattern(longdash) lwidth(medium) mlabformat(%9.2fc) mlabposition(12) msize(small) mlabcolor(gs5) mcolor(navy) lcolor(navy)) ///        
        (line controlmean FF_one if D_treatment == 2,  lwidth(medthick) lcolor(gs5) lpattern(dot)) ///
        (line unrelatedmean FF_one if D_treatment == 3, lwidth(medthick) lcolor(lavender) lpattern(dot)) ///
        (line relatedmean FF_one if D_treatment == 4, lwidth(medthick) lcolor(navy) lpattern(dot)) ///
        , legend(order(1 "Control" 2 "T1: Unrelated" 3 "T2: Dilemma-related" 4 "DEL")) ///
          xtitle(number of family members and friends in group) ytitle("average contributions") ///
          ysc(r(0 10)) ylabel(0(2)10, grid) graphregion(color(white)) bgcolor(white)
		  
twoway  /// 
        (scatter contribution_meanFFT2 FF_one if D_treatment == 2, connect(direct) sort(FF_one) mlabel(contribution_meanFFT2) lpattern(solid) lwidth(medium) mlabformat(%9.2fc) mlabposition(12) msize(small) mlabcolor(gs5) mcolor(gs5) lcolor(gs5)) ///  
        (scatter contribution_meanFFT3 FF_one if D_treatment == 3, connect(direct) sort(FF_one) mlabel(contribution_meanFFT3) lpattern(dash) lwidth(medium) mlabformat(%9.2fc) mlabposition(6) msize(small) mlabcolor(gs5) mcolor(lavender) lcolor(lavender)) ///  
        (scatter contribution_meanFFT4 FF_one if D_treatment == 4, connect(direct) sort(FF_one) mlabel(contribution_meanFFT4) lpattern(longdash) lwidth(medium) mlabformat(%9.2fc) mlabposition(12) msize(small) mlabcolor(gs5) mcolor(navy) lcolor(navy)) ///        
        (line controlmean FF_one if D_treatment == 2,  lwidth(medthick) lcolor(gs5) lpattern(dot)) ///
        (line unrelatedmean FF_one if D_treatment == 3, lwidth(medthick) lcolor(lavender) lpattern(dot)) ///
        (line relatedmean FF_one if D_treatment == 4, lwidth(medthick) lcolor(navy) lpattern(dot)) ///
        , legend(order(1 "Control" 2 "T1: Unrelated" 3 "T2: Dilemma-related" 4 "DEL")) ///
          xtitle(number of family members and friends in group) ytitle("average contributions") ///
          ysc(r(0 10)) ylabel(0(2)10, grid) graphregion(color(white)) bgcolor(white)

restore




  


*** Table 7: Marginal effects for Tobit estimations with interaction effects *** 
** -> see average marginal effects reported right after regression models (Table 6)
 
 
 




 
//////// ************               APPENDIX               ************ ////////
 


*** A.1: Map of selected villages ***
* -> no data used
 


*** A.2: Formalized description of public good game payoffs ***
* -> no data used
 


*** A.3: Poster used to explain the public good game ***
* -> no data used



*** A.4: Distribution social ties across experimental conditions ***
tabulate  Unknown D_treatment if D_treatment > 1
tabulate  Acquaintancies D_treatment if D_treatment > 1
tabulate  Friends D_treatment if D_treatment > 1
tabulate  Family D_treatment if D_treatment > 1
   


*** A.5: Distribution of contributions ***
label define graphlabel 1 "non" 2 "Control" 3 "T1: Unrelated" 4  "T2: Dilemma-related"
label values D_treatment graphlabel
twoway (histogram D_contribute if D_treatment == 2, by(D_treatment, style(compact) graphregion(color(white)) bgcolor(white) note("") ) discrete frequency lcolor(gs2) fcolor(gs13) lwidth(mediumthick) gap(5) graphregion(color(white)) bgcolor(white) ), xtitle(contribution to public good) ytitle("frequency") ysc(r(0 30)) ylabel(0(10)30, grid)

twoway (histogram D_contribute if D_treatment == 3, by(D_treatment, style(compact) graphregion(color(white)) bgcolor(white) note("") ) discrete frequency lcolor(gs2) fcolor(gs13) lwidth(mediumthick) gap(5) graphregion(color(white)) bgcolor(white) ), xtitle(contribution to public good) ytitle("frequency") ysc(r(0 30)) ylabel(0(10)30, grid)

twoway (histogram D_contribute if D_treatment == 4, by(D_treatment, style(compact) graphregion(color(white)) bgcolor(white) note("") ) discrete frequency lcolor(gs2) fcolor(gs13) lwidth(mediumthick) gap(5) graphregion(color(white)) bgcolor(white) ), xtitle(contribution to public good) ytitle("frequency") ysc(r(0 30)) ylabel(0(10)30, grid)

 

 
 *** A.6: Full Tobit regression models for contributions  ***
 
 **A.6.1: Tobit regression: contribution - basic models  **
* -> see main section for Table 6 (only a shortened version without socioeconomic control is reported in the main text of the paper)
 
 **A.6.2: Tobit regression: contribution - models with interaction effects  **
* -> see main section for Table 6 (only a shortened version without socioeconomic control is reported in the main text of the paper)



*** A.7 Alternative regression model specifications: contributions ***

** A.7.1 Tobit regression: contribution – basic models without expectations
* Tobit, model 1
tobit D_contribute   T_Smalltalk T_Coordination if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store model_1
* Tobit, model 2
tobit D_contribute T_Smalltalk T_Coordination FamFds `socioeconomics' `agriculturals' `experimentereffects'   if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store NEmodel_2
* Tobit, model 3
tobit D_contribute   T_Smalltalk T_Coordination if D_treatment > 1 & Control_wrong == 0, ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store model_3
* Tobit, model 4
tobit D_contribute T_Smalltalk T_Coordination FamFds `socioeconomics' `agriculturals' `experimentereffects'   if D_treatment > 1 & Control_wrong == 0, ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store NEmodel_4

estout model_1 NEmodel_2 model_3 NEmodel_4 , cells(b(star fmt(3)) se(nopar fmt(2))) label legend varlabels(_cons constant) stats(N, fmt(3 3 3 0) label(N))  starlevels(* 0.05 ** 0.01 *** 0.001)



** A.7.2 Tobit regression: contribution - models with i.e.s without expectations
* Tobit, model 5
tobit D_contribute   T_Smalltalk##c.FamFds T_Coordination##c.FamFds  `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins, dydx(T_Smalltalk T_Coordination) at(FamFds=(0 1 2 3)) 
estimates store NEmodel_5
* Tobit, model 6
tobit D_contribute   T_Smalltalk##i.FamFds T_Coordination##i.FamFds  `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins FamFds, dydx(T_Smalltalk T_Coordination) atmeans
estimates store NEmodel_6
* Tobit, model 7
tobit D_contribute   T_Smalltalk##c.FamFds T_Coordination##c.FamFds  `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 & Control_wrong == 0, ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins, dydx(T_Smalltalk T_Coordination) at(FamFds=(0 1 2 3)) 
estimates store NEmodel_7
* Tobit, model 8
tobit D_contribute   T_Smalltalk##i.FamFds T_Coordination##i.FamFds  `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 & Control_wrong == 0, ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins FamFds, dydx(T_Smalltalk T_Coordination) atmeans
estimates store NEmodel_8

estout NEmodel_5 NEmodel_6 NEmodel_7 NEmodel_8 , cells(b(star fmt(3)) se(nopar fmt(2))) label legend varlabels(_cons constant) stats(N, fmt(3 3 3 0) label(N))  starlevels(* 0.05 ** 0.01 *** 0.001)



** A.7.3 OLS regression: contribution - basic models
* OLS, model 1
reg D_contribute   T_Smalltalk T_Coordination if D_treatment > 1 , vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store OLSmodel_1
* OLS, model 2
reg D_contribute Belief T_Smalltalk T_Coordination FamFds `socioeconomics' `agriculturals' `experimentereffects'   if D_treatment > 1 , vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store OLSmodel_2
* OLS, model 3
reg D_contribute   T_Smalltalk T_Coordination if D_treatment > 1 & Control_wrong == 0, vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store OLSmodel_3
* OLS, model 4
reg D_contribute Belief T_Smalltalk T_Coordination FamFds `socioeconomics' `agriculturals' `experimentereffects'   if D_treatment > 1 & Control_wrong == 0, vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store OLSmodel_4

estout OLSmodel_1 OLSmodel_2 OLSmodel_3 OLSmodel_4 , cells(b(star fmt(3)) se(nopar fmt(2))) label legend varlabels(_cons constant) stats(N, fmt(3 3 3 0) label(N))  starlevels(* 0.05 ** 0.01 *** 0.001)


** A.7.4 OLS regression: contribution - models with interaction effects
* OLS, model 5
reg D_contribute   T_Smalltalk##c.FamFds T_Coordination##c.FamFds Belief `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 , vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins, dydx(T_Smalltalk T_Coordination) at(FamFds=(0 1 2 3)) 
estimates store OLSmodel_5
* OLS, model 6
reg D_contribute   T_Smalltalk##i.FamFds T_Coordination##i.FamFds Belief `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 , vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins FamFds, dydx(T_Smalltalk T_Coordination) atmeans
estimates store OLSmodel_6
* OLS, model 7
reg D_contribute   T_Smalltalk##c.FamFds T_Coordination##c.FamFds Belief `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 & Control_wrong == 0, vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins, dydx(T_Smalltalk T_Coordination) at(FamFds=(0 1 2 3)) 
estimates store OLSmodel_7
* OLS, model 8
reg D_contribute   T_Smalltalk##i.FamFds T_Coordination##i.FamFds Belief `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 & Control_wrong == 0, vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins FamFds, dydx(T_Smalltalk T_Coordination) atmeans
estimates store OLSmodel_8

estout OLSmodel_5 OLSmodel_6 OLSmodel_7 OLSmodel_8, cells(b(star fmt(3))  se(nopar fmt(2))) label legend varlabels(_cons constant) stats(N, fmt(3 3 3 0) label(N))  starlevels(* 0.05 ** 0.01 *** 0.001)  





*** A.8: Contributions by treatment conditions and social contexts *** 
tab FamFds if D_treatment == 2, sum (D_contribute)
tab FamFds if D_treatment == 3, sum (D_contribute)
tab FamFds if D_treatment == 4, sum (D_contribute)
** test for differences in contributions for each value of FdsFam, across all treatments: 
* ANOVA
anova D_contribute FamFds if D_treatment == 2
anova D_contribute FamFds if D_treatment == 3
anova D_contribute FamFds if D_treatment == 4
oneway D_contribute FamFds if D_treatment == 2
oneway D_contribute FamFds if D_treatment == 3
oneway D_contribute FamFds if D_treatment == 4
pwmean D_contribute if D_treatment == 2, over(FamFds) mcompare(tukey) effects
pwmean D_contribute if D_treatment == 3, over(FamFds) mcompare(tukey) effects
pwmean D_contribute if D_treatment == 4, over(FamFds) mcompare(tukey) effects
* Kruskall Wallis
kwallis D_contribute if D_treatment == 2, by(FamFds) 
kwallis D_contribute if D_treatment == 3, by(FamFds) 
kwallis D_contribute if D_treatment == 4, by(FamFds) 




*** A.9 Comprehension ***

**A.9.1 Comparison correctly and incorrectly answered control questions

* test for differences in contributions between right and wrong CQS, within treatments: 
* testing for significant differences between single treatments: TTEST
ttest D_contribute if  D_treatment ==2 , by(Control_wrong) // 
ttest D_contribute if  D_treatment ==3 , by(Control_wrong) // 
ttest D_contribute if  D_treatment ==4 , by(Control_wrong) // 

* 1. correct CQ:
* testing for significant differences between single treatments: TTEST
ttest D_contribute if Control_wrong == 0 & D_treatment ==2 | Control_wrong == 0 &D_treatment == 3, by(D_treatment) // *
ttest D_contribute if Control_wrong == 0 & D_treatment ==2 | Control_wrong == 0 &D_treatment == 4, by(D_treatment) // ***
ttest D_contribute if Control_wrong == 0 & D_treatment ==3 | Control_wrong == 0 &D_treatment == 4, by(D_treatment) // ***

* number of wrong answers, tsted by CHI2
tab  D_treatment , sum(Control_wrong)
tab D_treatment Control_wrong if D_treatment ==2 | D_treatment == 3 , chi2 // 
tab D_treatment Control_wrong if D_treatment ==2 | D_treatment == 4 , chi2 // ***
tab D_treatment Control_wrong if D_treatment ==3 | D_treatment == 4 , chi2 // **

* 2. wrong CQ:
* testing for significant differences between single treatments: TTEST
ttest D_contribute if Control_wrong == 1 & D_treatment ==2 | Control_wrong == 1 &D_treatment == 3, by(D_treatment) // 
ttest D_contribute if Control_wrong == 1 & D_treatment ==2 | Control_wrong == 1 &D_treatment == 4, by(D_treatment) // 
ttest D_contribute if Control_wrong == 1 & D_treatment ==3 | Control_wrong == 1 &D_treatment == 4, by(D_treatment) // 

* table for paper:
eststo OutcomeT2c: quietly estpost summarize D_contribute Belief TrustGroup  if D_treatment ==2 
eststo OutcomeT3c: quietly estpost summarize D_contribute Belief TrustGroup  if D_treatment ==3
eststo OutcomeT4c: quietly estpost summarize D_contribute Belief TrustGroup  if D_treatment ==4 
esttab OutcomeT2c OutcomeT3c OutcomeT4c , cells("mean( fmt(2)) sd") label 



**A.9.2 Figure comprehension share
gen controls_correct = 1
replace controls_correct = 0 if Control_wrong == 1
graph bar (mean) controls_correct if D_treatment > 1, over(L_treatment, sort(D_treatment)) blabel(bar, format(%9.2f)) ytitle(mean of Contribution)   ylabel(0(0.2)1, angle(0))ytitle("share correctly answered control questions") graphregion(color(white)) bgcolor(white) bar(1, bcolor(gs9))



** A.9.3 Figure comprehension and contributions
* understood only
preserve
label define Treatlabels 1 "Anonymity" 2 "No Communication" 3 "Unrelated Communication" 4 "Dilemma-related communication"
label values D_treatment Treatlabels
drop if Control_wrong == 1
collapse (mean) meancontribute = D_contribute (sd) sdcontribute= D_contribute (count) n = D_contribute, by (D_treatment)
generate hicontribute = meancontribute + invttail(n-1,0.025)*(sdcontribute / sqrt(n))
generate locontribute = meancontribute - invttail(n-1,0.025)*(sdcontribute / sqrt(n))
gen double meancontribute_db = round(meancontribute, 0.01)
drop if D_treatment == 1
twoway (bar meancontribute_db D_treatment, bcolor(gs9) barwidth (0.55)) (rcap hicontribute locontribute D_treatment, lcolor(gs2) lwidth(medthick)) (scatter meancontribute_db D_treatment, msymbol(none) mlabel(meancontribute_db) mlabposition(1) mlabcolor(black) mlabformat(%9.2fc) ), legend (order(1 "mean" 2 "95% CI") size(small)) ytitle("contributions to public good") xtitle("") ysc(r(0 10)) ylabel(0(2)10, grid)  xlabel( 2 "No communication" 3 "T1: Unrelated" 4 "T2: Dilemma-related", labsize(small)) xsize(5) ysize(5) xscale(range(1.45 4.55)) graphregion(color(white)) bgcolor(white) 
restore

* misunderstood only
preserve
label define Treatlabels 1 "Anonymity" 2 "No Communication" 3 "Unrelated Communication" 4 "Dilemma-related communication"
label values D_treatment Treatlabels
drop if Control_wrong == 0
collapse (mean) meancontribute = D_contribute (sd) sdcontribute= D_contribute (count) n = D_contribute, by (D_treatment)
generate hicontribute = meancontribute + invttail(n-1,0.025)*(sdcontribute / sqrt(n))
generate locontribute = meancontribute - invttail(n-1,0.025)*(sdcontribute / sqrt(n))
gen double meancontribute_db = round(meancontribute, 0.01)
drop if D_treatment == 1
twoway (bar meancontribute_db D_treatment, bcolor(gs9) barwidth (0.55)) (rcap hicontribute locontribute D_treatment, lcolor(gs2) lwidth(medthick)) (scatter meancontribute_db D_treatment, msymbol(none) mlabel(meancontribute_db) mlabposition(1) mlabcolor(black) mlabformat(%9.2fc) ), legend (order(1 "mean" 2 "95% CI") size(small)) ytitle("contributions to public good") xtitle("") ysc(r(0 10)) ylabel(0(2)10, grid)  xlabel( 2 "No communication" 3 "T1: Unrelated" 4 "T2: Dilemma-related", labsize(small)) xsize(5) ysize(5) xscale(range(1.45 4.55)) graphregion(color(white)) bgcolor(white) 
restore


** A.9.4 Regressions: comprehension - without socioeconomics

reg Control_wrong  T_Smalltalk T_Coordination   if D_treatment > 1 , vce(cluster Gamegroup_ID)
estimates store Reg_Comprehension_OLS
probit Control_wrong  T_Smalltalk T_Coordination  if D_treatment > 1 , vce(cluster Gamegroup_ID)
estimates store Reg_Comprehension_Probit
tobit D_contribute Control_wrong  T_Smalltalk T_Coordination  if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
estimates store Reg_ContribComp_OLS

estout  Reg_Comprehension_OLS Reg_Comprehension_Probit Reg_ContribComp_OLS, cells(b(star fmt(3)) se(nopar fmt(2))) label legend varlabels(_cons constant) stats(N, fmt(3 3 3 0) label(N))  starlevels(* 0.05 ** 0.01 *** 0.001)



** A.9.5 Regressions: comprehension - with socioeconomics

reg Control_wrong  T_Smalltalk T_Coordination  FamFds `socioeconomics' `agriculturals' `experimentereffects'    if D_treatment > 1 , vce(cluster Gamegroup_ID)
estimates store Reg_Comprehension_OLSSE
probit Control_wrong  T_Smalltalk T_Coordination  FamFds `socioeconomics' `agriculturals' `experimentereffects'   if D_treatment > 1 , vce(cluster Gamegroup_ID)
estimates store Reg_Comprehension_ProbitSE
tobit D_contribute Control_wrong  T_Smalltalk T_Coordination  FamFds `socioeconomics' `agriculturals' `experimentereffects'   if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
estimates store Reg_ContribComp_OLSSE

estout  Reg_Comprehension_OLSSE Reg_Comprehension_ProbitSE Reg_ContribComp_OLSSE, cells(b(star fmt(3)) se(nopar fmt(2))) label legend varlabels(_cons constant) stats(N, fmt(3 3 3 0) label(N))  starlevels(* 0.05 ** 0.01 *** 0.001)




*** A.10 Expectations ***

** A.10.1 Figure Expectations

preserve
label define Treatlabels 1 "Anonymity" 2 "Identification" 3 "Unrelated Communication" 4 "Dilemma-related communication"
label values D_treatment Treatlabels
collapse (mean) meanexpect = Belief (sd) sdexpect= Belief (count) n = Belief, by (D_treatment)
generate hiexpect = meanexpect + invttail(n-1,0.025)*(sdexpect / sqrt(n))
generate loexpect = meanexpect - invttail(n-1,0.025)*(sdexpect / sqrt(n))
gen double meanexpect_db = round(meanexpect, 0.01)
drop if D_treatment == 1
twoway (bar meanexpect_db D_treatment, bcolor(gs9) barwidth (0.55)) (rcap hiexpect loexpect D_treatment, lcolor(gs2) lwidth(medthick)) (scatter meanexpect_db D_treatment, msymbol(none) mlabel(meanexpect_db) mlabposition(1) mlabcolor(black) mlabformat(%9.2fc) ), legend (order(1 "mean" 2 "95% CI") size(small)) ytitle("expectations") xtitle("") ysc(r(0 10)) ylabel(0(2)10, grid)  xlabel( 2 "No communication" 3 "T1: Unrelated" 4 "T2: Dilemma-related", labsize(small)) xsize(5) ysize(5) xscale(range(1.45 4.55)) graphregion(color(white)) bgcolor(white) 
restore


** A.10.2 Tobit regression: expectations – basic models

* Tobit, Bmodel 1
tobit Belief   T_Smalltalk T_Coordination if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store Bmodel_1
* Tobit, Bmodel 2
tobit  Belief T_Smalltalk T_Coordination FamFds `socioeconomics' `agriculturals' `experimentereffects'   if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store Bmodel_2
* Tobit, Bmodel 3
tobit  Belief  T_Smalltalk T_Coordination if D_treatment > 1 & Control_wrong == 0, ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store Bmodel_3
* Tobit, Bmodel 4
tobit  Belief T_Smalltalk T_Coordination FamFds `socioeconomics' `agriculturals' `experimentereffects'   if D_treatment > 1 & Control_wrong == 0, ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
estimates store Bmodel_4

estout Bmodel_1 Bmodel_2 Bmodel_3 Bmodel_4 , cells(b(star fmt(3)) se(nopar fmt(2))) label legend varlabels(_cons constant) stats(N, fmt(3 3 3 0) label(N))  starlevels(* 0.05 ** 0.01 *** 0.001)





** A.10.3 Tobit regression: expectation – models with interaction effects

* Tobit, Bmodel 5
tobit Belief   T_Smalltalk##c.FamFds T_Coordination##c.FamFds  `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins, dydx(T_Smalltalk T_Coordination) at(FamFds=(0 1 2 3)) 
estimates store Bmodel_5
* Tobit, Bmodel 6
tobit Belief   T_Smalltalk##i.FamFds T_Coordination##i.FamFds  `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins FamFds, dydx(T_Smalltalk T_Coordination) atmeans
estimates store Bmodel_6
* Tobit, Bmodel 7
tobit Belief   T_Smalltalk##c.FamFds T_Coordination##c.FamFds  `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 & Control_wrong == 0, ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins, dydx(T_Smalltalk T_Coordination) at(FamFds=(0 1 2 3)) 
estimates store Bmodel_7
* Tobit, Bmodel 8
tobit Belief   T_Smalltalk##i.FamFds T_Coordination##i.FamFds  `socioeconomics' `agriculturals' `experimentereffects'     if D_treatment > 1 & Control_wrong == 0, ll(0) ul(10) vce(cluster Gamegroup_ID)
margins , dydx(T_Smalltalk T_Coordination) atmeans
margins FamFds, dydx(T_Smalltalk T_Coordination) atmeans
estimates store Bmodel_8

estout Bmodel_5 Bmodel_6 Bmodel_7 Bmodel_8 , cells(b(star fmt(3)) se(nopar fmt(2))) label legend varlabels(_cons constant) stats(N, fmt(3 3 3 0) label(N))  starlevels(* 0.05 ** 0.01 *** 0.001)



*** A.11 Trust ***

** A.11.1 Figure trust

preserve
label define Treatlabels 1 "Anonymity" 2 "Identification" 3 "Unrelated Communication" 4 "Dilemma-related communication"
label values D_treatment Treatlabels
collapse (mean) meantrust = TrustGroup (sd) sdtrust= TrustGroup (count) n = TrustGroup, by (D_treatment)
generate hitrust = meantrust + invttail(n-1,0.025)*(sdtrust / sqrt(n))
generate lotrust = meantrust - invttail(n-1,0.025)*(sdtrust / sqrt(n))
gen double meantrust_db = round(meantrust, 0.01)
drop if D_treatment == 1
twoway (bar meantrust_db D_treatment, bcolor(gs9) barwidth (0.55)) (rcap hitrust lotrust D_treatment, lcolor(gs2) lwidth(medthick)) (scatter meantrust_db D_treatment, msymbol(none) mlabel(meantrust_db) mlabposition(1) mlabcolor(black) mlabformat(%9.2fc) ), legend (order(1 "mean" 2 "95% CI") size(small)) ytitle("trust in group members") xtitle("") ysc(r(1 4)) ylabel(1(1)4, grid)  xlabel( 2 "No communication" 3 "T1: Unrelated" 4 "T2: Dilemma-related", labsize(small)) xsize(5) ysize(5) xscale(range(1.45 4.55)) graphregion(color(white)) bgcolor(white) 
restore


** A.11.2 Regressions: trust

oprobit TrustGroup T_Smalltalk T_Coordination FamFds if D_treatment > 1 ,  vce(cluster Gamegroup_ID)
estimates store Reg_TrustDep
oprobit  TrustGroup T_Smalltalk T_Coordination FamFds `socioeconomics' `agriculturals' `experimentereffects'  if D_treatment > 1 ,  vce(cluster Gamegroup_ID)
estimates store Reg_TrustDep_controls

tobit D_contribute TrustGroup  if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
estimates store Reg_Trust
tobit D_contribute  TrustGroup T_Smalltalk T_Coordination FamFds  `socioeconomics' `agriculturals' `experimentereffects'  if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
estimates store Reg_Trust_controls

tobit Belief TrustGroup   if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
estimates store Reg_TrustBelief
tobit Belief TrustGroup T_Smalltalk T_Coordination FamFds   `socioeconomics' `agriculturals' `experimentereffects' if D_treatment > 1 , ll(0) ul(10) vce(cluster Gamegroup_ID)
estimates store Reg_TrustBelief_controls

estout Reg_TrustDep Reg_Trust Reg_TrustBelief , cells(b(star fmt(3)) se(nopar fmt(2))) label legend varlabels(_cons constant) stats(N, fmt(3 3 3 0) label(N))  starlevels(* 0.05 ** 0.01 *** 0.001)
estout Reg_TrustDep_controls Reg_Trust_controls Reg_TrustBelief_controls , cells(b(star fmt(3)) se(nopar fmt(2))) label legend varlabels(_cons constant) stats(N, fmt(3 3 3 0) label(N))  starlevels(* 0.05 ** 0.01 *** 0.001)




* - end of do-file - *




